# kitsiso

Library for sending [desktop notifications](https://people.gnome.org/~mccann/docs/notification-spec/notification-spec-latest.html).

For more information see the [documentation](https://andreas19.github.io/kitsiso/overview.html).

*Kitsiso* means [*notification*](https://glosbe.com/en/tn/notification) in [Setswana](https://en.wikipedia.org/wiki/Tswana_language).
